@@ -19,6 +19,7 @@
 
 #include "SettingsBase.h"
 #include "BaseConfig.h"
+#include "systemsettings_app_debug.h"
 
 #include <QTimer>
 #include <QRadioButton>
@@ -46,14 +47,14 @@ SettingsBase::SettingsBase( QWidget * parent )
     : KXmlGuiWindow(parent)
 {
     // Ensure delayed loading doesn't cause a crash
-    activeView = 0;
-    aboutDialog = 0;
-    configDialog = 0;
-    lostFound = 0;
+    activeView = nullptr;
+    aboutDialog = nullptr;
+    configDialog = nullptr;
+    lostFound = nullptr;
     // Prepare the view area
     stackedWidget = new QStackedWidget( this );
     setWindowTitle(i18n("System Settings"));
-    setWindowIcon(QIcon::fromTheme("preferences-system"));
+    setWindowIcon(QIcon::fromTheme(QStringLiteral("preferences-system")));
     setCentralWidget(stackedWidget);
     setWindowFlags( windowFlags() | Qt::WindowContextHelpButtonHint );
     // Initialise search
@@ -77,18 +78,21 @@ SettingsBase::~SettingsBase()
 
 QSize SettingsBase::sizeHint() const
 {
-    qreal factor = qBound(1., QGuiApplication::primaryScreen()->physicalDotsPerInch()/96., 3.);
 
-    return QSize(720*factor, 600*factor);
+    // on smaller or portrait-rotated screens, do not max out height and/or width
+    const QSize screenSize = (QGuiApplication::primaryScreen()->availableSize()*0.9);
+    const QSize targetSize = QSize(1024, 700);
+    return targetSize.boundedTo(screenSize);
+
 }
 
 void SettingsBase::initApplication()
 {
     // Prepare the menu of all modules
-    categories = KServiceTypeTrader::self()->query("SystemSettingsCategory");
-    modules = KServiceTypeTrader::self()->query("KCModule", "[X-KDE-System-Settings-Parent-Category] != ''");
-    modules += KServiceTypeTrader::self()->query("SystemSettingsExternalApp");
-    rootModule = new MenuItem( true, 0 );
+    categories = KServiceTypeTrader::self()->query(QStringLiteral("SystemSettingsCategory"));
+    modules = KServiceTypeTrader::self()->query(QStringLiteral("KCModule"), QStringLiteral("[X-KDE-System-Settings-Parent-Category] != ''"));
+    modules += KServiceTypeTrader::self()->query(QStringLiteral("SystemSettingsExternalApp"));
+    rootModule = new MenuItem( true, nullptr );
     initMenuList(rootModule);
     // Handle lost+found modules...
     if (lostFound) {
@@ -96,14 +100,14 @@ void SettingsBase::initApplication()
             const KService::Ptr entry = modules.at(i);
             MenuItem * infoItem = new MenuItem(false, lostFound);
             infoItem->setService( entry );
-            qDebug() << "Added " << entry->name();
+            qCDebug(SYSTEMSETTINGS_APP_LOG) << "Added " << entry->name();
         }
     }
 
     // Prepare the Base Data
     BaseData::instance()->setMenuItem( rootModule );
     // Load all possible views
-    const KService::List pluginObjects = KServiceTypeTrader::self()->query( "SystemSettingsView" );
+    const KService::List pluginObjects = KServiceTypeTrader::self()->query( QStringLiteral("SystemSettingsView") );
     const int nbPlugins = pluginObjects.count();
     for( int pluginsDone = 0; pluginsDone < nbPlugins ; ++pluginsDone ) {
         KService::Ptr activeService = pluginObjects.at( pluginsDone );
@@ -117,12 +121,15 @@ void SettingsBase::initApplication()
             connect(searchText, &KLineEdit::textChanged, controller, &BaseMode::searchChanged);
             connect(controller, &BaseMode::viewChanged, this, &SettingsBase::viewChange);
         } else {
-            qWarning() << "View load error: " + error;
+            qCWarning(SYSTEMSETTINGS_APP_LOG) << QStringLiteral("View load error: ") + error;
         }
     }
     searchText->completionObject()->setIgnoreCase( true );
     searchText->completionObject()->setItems( BaseData::instance()->menuItem()->keywords() );
     changePlugin();
+
+    // enforce minimum window size
+    setMinimumSize(SettingsBase::sizeHint());
     activateWindow();
 }
 
@@ -130,51 +137,50 @@ void SettingsBase::initToolBar()
 {
     // Fill the toolbar with default actions
     // Exit is the very last action
-    quitAction = actionCollection()->addAction( KStandardAction::Quit, "quit_action", this, SLOT(close()) );
+    quitAction = actionCollection()->addAction( KStandardAction::Quit, QStringLiteral("quit_action"), this, SLOT(close()) );
     // Configure goes at the end
-    configureAction = actionCollection()->addAction( KStandardAction::Preferences, "configure", this, SLOT(configShow()) );
+    configureAction = actionCollection()->addAction( KStandardAction::Preferences, QStringLiteral("configure"), this, SLOT(configShow()) );
     actionCollection()->setDefaultShortcut(configureAction, QKeySequence(Qt::CTRL + Qt::Key_M));
     configureAction->setText( i18n("Configure") );
     // Help after it
     initHelpMenu();
-    configureAction->setIcon(QIcon::fromTheme("settings-configure"));
+    configureAction->setIcon(QIcon::fromTheme(QStringLiteral("application-menu")));
 
     // Then a spacer so the search line-edit is kept separate
     spacerAction = new QWidgetAction( this );
     spacerAction->setDefaultWidget(spacerWidget);
-    actionCollection()->addAction( "spacer", spacerAction );
+    actionCollection()->addAction( QStringLiteral("spacer"), spacerAction );
     // Finally the search line-edit
     searchAction = new QWidgetAction( this );
     searchAction->setDefaultWidget(searchText);
     actionCollection()->setDefaultShortcut(searchAction, QKeySequence(Qt::CTRL + Qt::Key_F));
     connect( searchAction, SIGNAL(triggered(bool)), searchText, SLOT(setFocus()));
-    actionCollection()->addAction( "searchText", searchAction );
+    actionCollection()->addAction( QStringLiteral("searchText"), searchAction );
     // Initialise the Window
     setupGUI(Save|Create,QString());
     menuBar()->hide();
 
     // Toolbar & Configuration
-    helpActionMenu->setMenu( dynamic_cast<QMenu*>( factory()->container("help", this) ) );
-    setMinimumSize(620,430);
+    helpActionMenu->setMenu( dynamic_cast<QMenu*>( factory()->container(QStringLiteral("help"), this) ) );
     toolBar()->setMovable(false); // We don't allow any changes
     changeToolBar( BaseMode::Search | BaseMode::Configure );
 }
 
 void SettingsBase::initHelpMenu()
 {
-    helpActionMenu = new KActionMenu( QIcon::fromTheme("help-contents"), i18n("Help"), this );
+    helpActionMenu = new KActionMenu( QIcon::fromTheme(QStringLiteral("help-contents")), i18n("Help"), this );
     helpActionMenu->setDelayed( false );
-    actionCollection()->addAction( "help_toolbar_menu", helpActionMenu );
+    actionCollection()->addAction( QStringLiteral("help_toolbar_menu"), helpActionMenu );
     // Add the custom actions
-    aboutModuleAction = actionCollection()->addAction( KStandardAction::AboutApp, "help_about_module", this, SLOT(about()) );
-    changeAboutMenu( 0, aboutModuleAction, i18n("About Active Module") );
-    aboutViewAction = actionCollection()->addAction( KStandardAction::AboutApp, "help_about_view", this, SLOT(about()) );
+    aboutModuleAction = actionCollection()->addAction( KStandardAction::AboutApp, QStringLiteral("help_about_module"), this, SLOT(about()) );
+    changeAboutMenu( nullptr, aboutModuleAction, i18n("About Active Module") );
+    aboutViewAction = actionCollection()->addAction( KStandardAction::AboutApp, QStringLiteral("help_about_view"), this, SLOT(about()) );
 }
 
 void SettingsBase::initConfig()
 {
     // Prepare dialog first
-    configDialog = new KConfigDialog( this, "systemsettingsconfig", BaseConfig::self() );
+    configDialog = new KConfigDialog( this, QStringLiteral("systemsettingsconfig"), BaseConfig::self() );
     configDialog->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
 
     // Add our page
@@ -192,7 +198,6 @@ void SettingsBase::initConfig()
         viewSelection.addButton( radioButton, possibleViews.values().indexOf(mode) );
     }
     configWidget.GbViewStyle->setLayout( configLayout );
-    configWidget.GbViewStyle->setVisible( possibleViews.count() > 1 );
     KWindowConfig::restoreWindowSize(configDialog->windowHandle(), KSharedConfig::openConfig()->group("ConfigDialog"));
     connect(configDialog, &KConfigDialog::accepted, this, &SettingsBase::configUpdated);
 }
@@ -203,14 +208,14 @@ void SettingsBase::initMenuList(MenuItem * parent)
     // look for any categories inside this level, and recurse into them
     for (int i = 0; i < categories.size(); ++i) {
         const KService::Ptr entry = categories.at(i);
-        const QString parentCategory = entry->property("X-KDE-System-Settings-Parent-Category").toString();
-        const QString parentCategory2 = entry->property("X-KDE-System-Settings-Parent-Category-V2").toString();
+        const QString parentCategory = entry->property(QStringLiteral("X-KDE-System-Settings-Parent-Category")).toString();
+        const QString parentCategory2 = entry->property(QStringLiteral("X-KDE-System-Settings-Parent-Category-V2")).toString();
         if ( parentCategory == parent->category() ||
              // V2 entries must not be empty if they want to become a proper category.
              ( !parentCategory2.isEmpty() && parentCategory2 == parent->category() ) ) {
             MenuItem * menuItem = new MenuItem(true, parent);
             menuItem->setService( entry );
-            if( menuItem->category() == "lost-and-found" ) {
+            if( menuItem->category() == QLatin1String("lost-and-found") ) {
                 lostFound = menuItem;
                 continue;
             }
@@ -223,8 +228,8 @@ void SettingsBase::initMenuList(MenuItem * parent)
     // scan for any modules at this level and add them
     for (int i = 0; i < modules.size(); ++i) {
         const KService::Ptr entry = modules.at(i);
-        const QString category = entry->property("X-KDE-System-Settings-Parent-Category").toString();
-        const QString category2 = entry->property("X-KDE-System-Settings-Parent-Category-V2").toString();
+        const QString category = entry->property(QStringLiteral("X-KDE-System-Settings-Parent-Category")).toString();
+        const QString category2 = entry->property(QStringLiteral("X-KDE-System-Settings-Parent-Category-V2")).toString();
         if( !parent->category().isEmpty() && (category == parent->category() || category2 == parent->category()) ) {
             if (!entry->noDisplay() ) {
                 // Add the module info to the menu
@@ -293,9 +298,9 @@ bool SettingsBase::queryClose()
 void SettingsBase::about()
 {
     delete aboutDialog;
-    aboutDialog = 0;
+    aboutDialog = nullptr;
 
-    const KAboutData * about = 0;
+    const KAboutData * about = nullptr;
     if( sender() == aboutViewAction ) {
         about = activeView->aboutData();
     } else if( sender() == aboutModuleAction && activeView->moduleView() ) {
@@ -303,7 +308,7 @@ void SettingsBase::about()
     }
 
     if( about ) {
-        aboutDialog = new KAboutApplicationDialog(*about, 0);
+        aboutDialog = new KAboutApplicationDialog(*about, nullptr);
         aboutDialog->show();
     }
 }
@@ -367,8 +372,8 @@ void SettingsBase::viewChange(bool state)
 
 void SettingsBase::updateViewActions()
 {
-    guiFactory()->unplugActionList( this, "viewActions" );
-    guiFactory()->plugActionList( this, "viewActions", activeView->actionsList() );
+    guiFactory()->unplugActionList( this, QStringLiteral("viewActions") );
+    guiFactory()->plugActionList( this, QStringLiteral("viewActions"), activeView->actionsList() );
 }
 
 void SettingsBase::changeToolBar( BaseMode::ToolBarItems toolbar )
@@ -376,23 +381,23 @@ void SettingsBase::changeToolBar( BaseMode::ToolBarItems toolbar )
     if( sender() != activeView ) {
         return;
     }
-    guiFactory()->unplugActionList( this, "configure" );
-    guiFactory()->unplugActionList( this, "search" );
-    guiFactory()->unplugActionList( this, "quit" );
+    guiFactory()->unplugActionList( this, QStringLiteral("configure") );
+    guiFactory()->unplugActionList( this, QStringLiteral("search") );
+    guiFactory()->unplugActionList( this, QStringLiteral("quit") );
     if ( BaseMode::Search & toolbar ) {
         QList<QAction*> searchBarActions;
         searchBarActions << spacerAction << searchAction;
-        guiFactory()->plugActionList( this, "search", searchBarActions );
+        guiFactory()->plugActionList( this, QStringLiteral("search"), searchBarActions );
     }
     if ( BaseMode::Configure & toolbar ) {
         QList<QAction*> configureBarActions;
         configureBarActions << configureAction;
-        guiFactory()->plugActionList( this, "configure", configureBarActions );
+        guiFactory()->plugActionList( this, QStringLiteral("configure"), configureBarActions );
     }
     if ( BaseMode::Quit & toolbar ) {
         QList<QAction*> quitBarActions;
         quitBarActions << quitAction;
-        guiFactory()->plugActionList( this, "quit", quitBarActions );
+        guiFactory()->plugActionList( this, QStringLiteral("quit"), quitBarActions );
     }
 
     toolBar()->setVisible(toolbar != BaseMode::NoItems || (activeView && activeView->actionsList().count() > 0));
