@@ -35,7 +35,7 @@ class SystemSettingsApp : public QApplication
 
 public:
    SystemSettingsApp(int& argc, char* argv[]);
-   ~SystemSettingsApp();
+   ~SystemSettingsApp() override;
 
    void setMainWindow(SettingsBase * main);
 
@@ -43,7 +43,7 @@ public Q_SLOTS:
    Q_SCRIPTABLE void quit();
 
 private:
-   SettingsBase * window; 
+   SettingsBase * window = nullptr;
 };
 
 #endif
