@@ -23,7 +23,7 @@
 
 #include <KPageView>
 #include <QWidget>
-#include <QtCore/QModelIndex>
+#include <QModelIndex>
 #include "systemsettingsview_export.h"
 
 class KAboutData;
@@ -55,14 +55,14 @@ public:
     /**
      * Constructs a ModuleView, with the parent specified.
      */
-    explicit ModuleView(QWidget * parent = 0);
+    explicit ModuleView(QWidget * parent = nullptr);
 
     /**
      * Destroys the module view, along with all modules loaded, and any changes present in them.
      *
-     * @warning The user will not be prompted to save changes if any exist.\n
+     * @warning The user will not be prompted to save changes if any exist.
      */
-    ~ModuleView();
+    ~ModuleView() override;
 
     /**
      * Provides the module information, which is used to set the caption of the window when either the
@@ -102,7 +102,7 @@ public Q_SLOTS:
      *
      * @param menuItem the QModelIndex that you want to load. Must be sourced from either MenuModel or MenuProxyModel
      */
-    void loadModule( QModelIndex menuItem );
+    void loadModule(const QModelIndex &menuItem );
 
     /**
      * Will open KHelpCenter, and load the help for the active module.
@@ -127,7 +127,7 @@ public Q_SLOTS:
     /**
      * Reimplemented for internal reasons.\n
      */
-    void keyPressEvent( QKeyEvent * event ) Q_DECL_OVERRIDE;
+    void keyPressEvent( QKeyEvent * event ) override;
 
 private:
     bool resolveChanges( KCModuleProxy *currentProxy );
